#!/usr/bin/python
# -*- coding: utf-8 -*- 
import getopt, sys, cv2 
import os, commands, re
#import numpy as np
from defcam import get_cameras, get_default

verbose = False
threshold = 70
dataset = 'data'
source = ''

short_opt = 'vhd:t:i:'
long_opt = [ 'help', 'dataset=', 'threshold=', 'image=' ] 

def usage():
    print( ( 'usage: {} [options]\n' +
             'options are:\n'
             '  -v                                       - verbose output\n' +
             '  -h               | --help                - this help\n' +
             '  -d <name>        | --dataset=<name>      - database title\n' +
             '  -t <number>      | --threshold=<number>  - treshhold level\n' +
             '  -i <file|number> | --image=<file|number> - video stream source' )
           .format( sys.argv[ 0 ] ) )
    return

def setParams():
    global verbose, threshold, dataset, source
    try:
        opts, args = getopt.gnu_getopt( sys.argv[ 1: ], short_opt, long_opt )
    except getopt.GetoptError as err:
        print( err )                                                  # will print something like "option -a not recognized"
        usage()
        sys.exit( 1 )   
    if verbose:
        print( 'options: {} | parameters: {}'.format( opts, args ) )
    if len( args ) != 0:
        print( 'there should be no parameters' )
        usage()
        sys.exit( 1 ) 
    for o, a in opts:
        if o == "-v":
            verbose = True
        elif o in ( "-h", "--help" ):
            usage()
            sys.exit()
        elif o in ( "-d", "--dataset"):
            dataset = a
        elif o in ( "-t", "--threshold"):
            try:
                threshold = int( a )
            except Exception as err:
                print( err ) 
                usage()
                sys.exit( 1 ) 
        elif o in ( "-i", "--image"):
            try:
                source = int( sys.argv[ 1 ] )
            except Exception as err:                                  # capture image file
                source = a
    return verbose, threshold, dataset, source 

def getCapture():
    if source == '':                                                  # images from default video camera
        cam = get_default()
        if cam < 0:
            print( "no video cameras available" )
            sys.exit( 1 )
        return cv2.VideoCapture( cam )
    elif isinstance( source, int ):
        if not source in get_cameras():
            print( "illegal camera #{}: ".format( source ) )
            sys.exit( 1 )
        return cv2.VideoCapture( source )
    else:                                                             # images from a video file
        if not os.path.exists( source ):
            print( 'inmage file {} not found'.format( source ) ) 
            exit( 1 )
        return cv2.VideoCapture( source )
  
def getImagesAndLabels( path ):
    # get path of all files in the folder
    imagePaths = [ os.path.join( path, f ) for f in os.listdir( path ) ] 
    faceSamples = []                                                  # create empty face list
    Ids = []                                                          # create empty ID list
    for imagePath in imagePaths:                                      # lLoop through all image paths
        image = cv2.imread( imagePath, cv2.IMREAD_LOAD_GDAL )         # чтение .jpg, .gif, .png etc.  
        if image.ndim > 2:                                            # convert image into grayscale
            image = cv2.cvtColor( image, cv2.COLOR_BGR2GRAY )
        # extract Id from the image file name
        Id = int( os.path.split( imagePath )[ -1 ].split( "." )[ 0 ] )
        # extract faces (!) from the training image sample
        faces = detect( image )                                       # 1 detector (xml) for all applications!
        # if only one face is detected, append the face and Id to list
        if 1 == len( faces ):
            x, y, w, h = faces[ 0 ]
            faceSamples.append( image[ y : y + h, x : x + w ] )
            Ids.append( Id )
    return faceSamples, Ids

xml = cv2.CascadeClassifier( 'haarcascade_frontalface_default.xml' )  # Load the classifier

def detect( frame ): 
    if frame.ndim > 2:                                                # Convert BGR to grayscale (if not yet)
        gray = cv2.cvtColor( frame, cv2.COLOR_BGR2GRAY )
    else: gray = frame
    if cv2.__version__ >= '3.0':
        rects, n = xml.detectMultiScale2( gray, scaleFactor = 1.15, minNeighbors = 4, 
                   minSize=( 30, 30 ), flags = cv2.CASCADE_SCALE_IMAGE )
    else:
        rects = xml.detectMultiScale( gray, minSize = ( 30, 30 ), \
                scaleFactor = 1.15, minNeighbors = 5, flags = 0 )
#    rects = xml.detectMultiScale( gray, minSize = ( 30, 30 ), \
#        scaleFactor = 1.15, minNeighbors = 5, flags = cv2.CASCADE_SCALE_IMAGE ) 
#    rects, r, w = xml.detectMultiScale3( gray, scaleFactor = 1.15, minNeighbors = 4, \
#        minSize=(30, 30), flags = cv2.CASCADE_SCALE_IMAGE, outputRejectLevels = True )
    return rects

'''
faces = faceCascade.detectMultiScale3( ...
rects = faces[0]
neighbours = faces[1]
weights = faces[2]
'''
