#!/usr/bin/python
# -*- coding: utf-8 -*- 
import cv2, sys, os
from comfuncs.defcam import get_cameras, get_default

def usage():
    print( 'usage: {} <out_file> [<camera>]'.format( sys.argv[ 0 ] ) )

if 0 == len( get_cameras() ):
    print( 'no camera was found' )
    sys.exit( 1 )
if 1 == len( sys.argv ) or len( sys.argv ) > 3:
    usage()
    sys.exit( 1 )
elif 2 == len( sys.argv ):
    dev = get_default()
    print( 'default camera {}'.format( dev ) )
    try:
        cap = cv2.VideoCapture( dev )
    except cv2.Exception as err:
        print( "illegal defaults" )
        sys.exit( 1 )
elif 3 == len( sys.argv ):
    try:
        dev = int( sys.argv[ 2 ] )
        if not dev in get_cameras():
            print( "illegal camera #{}: ".format( dev ) )
            sys.exit( 1 )
        try:
            cap = cv2.VideoCapture( dev )
        except cv2.Exception as err:
            print( "illegal camera #: " + str( err ) )
            sys.exit( 1 )
    except Exception as err:
        print( "illegal parameter: " + sys.argv[ 2 ] )
        sys.exit( 1 )

if cv2.__version__ >= '3.3':
    if not cv2.VideoCapture.isOpened( cap ):
        print( "no source captured!" )
        sys.exit( 1 )
    else:
        print( "capture open OK!" )

codec = ( 'DIVX', 'XVID', 'MJPG', 'X264', 'WMV1', 'WMV2' )
#fourcc = cv2.VideoWriter_fourcc( *codec[ 3 ] )       # Define the codec and create VideoWriter object
fourcc = cv2.VideoWriter_fourcc( *codec[ 1 ] )       # Define the codec and create VideoWriter object
#fourcc = cv2.VideoWriter_fourcc( *'X264' )       # Define the codec and create VideoWriter object
fpc = 25
try:
    out = cv2.VideoWriter( sys.argv[ 1 ], fourcc, fpc, ( 640, 480 ) )
except Exception as err:
    print( "error in output : " + str( err ) )
    sys.exit( 1 )

n = 0
while True:
    ret, frame = cap.read()                          # Capture frame-by-frame
    if not ret:
        break
    out.write( frame )                               # Write reading frame
    cv2.imshow( '', frame )                          # Display the resulting frame
    n += 1
    key = cv2.waitKey( 1 ) & 0xFF 
    if 27 == key or key == ord( 'q' ): break

cap.release()                                        # When everything done, release the capture
cv2.destroyAllWindows()
out.release()
print( 'saved {} frames'.format( n ) )

'''
https://docs.opencv.org/3.0-beta/doc/py_tutorials/py_gui/py_video_display/py_video_display.html

This time we create a VideoWriter object. We should specify the output file name (eg: output.avi). 
Then we should specify the FourCC code (details in next paragraph). Then number of frames per second (fps) 
and frame size should be passed. And last one is isColor flag. If it is True, encoder expect color frame, 
otherwise it works with grayscale frame.

FourCC is a 4-byte code used to specify the video codec. The list of available codes can be found in fourcc.org. 
It is platform dependent. Following codecs works fine for me.

In Fedora: DIVX, XVID, MJPG, X264, WMV1, WMV2. (XVID is more preferable. 
MJPG results in high size video. X264 gives very small size video)
In Windows: DIVX (More to be tested and added)
In OSX : (I don’t have access to OSX. Can some one fill this?)
FourCC code is passed as cv2.VideoWriter_fourcc('M','J','P','G') or cv2.VideoWriter_fourcc(*'MJPG) for MJPG.
'''
